@@ -1,16 +1,18 @@
 """``runway kbenv`` command group."""
 # docs: file://./../../../../docs/source/commands.rst
-from typing import Any
+from typing import Any, List
 
 import click
 
 from ... import options
 from ._install import install
+from ._list import list_installed
 from ._run import run
+from ._uninstall import uninstall
 
-__all__ = ["install", "run"]
+__all__ = ["install", "list_installed", "run", "uninstall"]
 
-COMMANDS = [install, run]
+COMMANDS: List[click.Command] = [install, list_installed, run, uninstall]
 
 
 @click.group("kbenv", short_help="kubectl (install|run)")
