@@ -1,17 +1,15 @@
-"""AWS ECS hook.
-
-A lot of this code exists to deal w/ the broken ECS connect_to_region
-function, and will be removed once this pull request is accepted:
-https://github.com/boto/boto/pull/3143
-
-"""
+"""AWS ECS hook."""
+# pylint: disable=no-self-argument,no-self-use
 from __future__ import annotations
 
 import logging
 from typing import TYPE_CHECKING, Any, Dict, List, Union
 
+from pydantic import validator
 from typing_extensions import TypedDict
 
+from ...utils import BaseModel
+
 if TYPE_CHECKING:
     from mypy_boto3_ecs.type_defs import CreateClusterResponseTypeDef
 
@@ -20,6 +18,20 @@ if TYPE_CHECKING:
 LOGGER = logging.getLogger(__name__)
 
 
+class CreateClustersHookArgs(BaseModel):
+    """Hook arguments for ``create_clusters``."""
+
+    clusters: List[str]
+    """List of cluster names to create."""
+
+    @validator("clusters", allow_reuse=True, pre=True)
+    def _convert_clusters(cls, v: Union[List[str], str]) -> List[str]:
+        """Convert value of ``clusters`` from str to list."""
+        if isinstance(v, str):
+            return [v]
+        return v
+
+
 class CreateClustersResponseTypeDef(TypedDict):
     """Response from create_clusters."""
 
@@ -27,22 +39,20 @@ class CreateClustersResponseTypeDef(TypedDict):
 
 
 def create_clusters(
-    context: CfnginContext, *, clusters: Union[List[str], str], **_: Any
+    context: CfnginContext, *__args: Any, **kwargs: Any
 ) -> CreateClustersResponseTypeDef:
     """Create ECS clusters.
 
     Args:
         context: CFNgin context object.
-        clusters: Names of clusters to create.
 
     """
-    conn = context.get_session().client("ecs")
-    if isinstance(clusters, str):
-        clusters = [clusters]
+    args = CreateClustersHookArgs.parse_obj(kwargs)
+    ecs_client = context.get_session().client("ecs")
 
     cluster_info: Dict[str, Any] = {}
-    for cluster in clusters:
+    for cluster in args.clusters:
         LOGGER.debug("creating ECS cluster: %s", cluster)
-        response = conn.create_cluster(clusterName=cluster)
+        response = ecs_client.create_cluster(clusterName=cluster)
         cluster_info[response.get("cluster", {}).get("clusterName", "")] = response
     return {"clusters": cluster_info}
